searchData={"items":[{"type":"module","title":"BookmarkParser","doc":"BookmarkParser is a library for parsing Netscape bookmark files.\n\nIt can parse bookmark files exported from browsers like Chrome, Firefox, Safari, etc.\nThe parser transforms the bookmarks into a tree structure of folders and entries.","ref":"BookmarkParser.html"},{"type":"module","title":"Examples - BookmarkParser","doc":"iex> content = \"\"\"\n    ...> <!DOCTYPE NETSCAPE-Bookmark-file-1>\n    ...>  \n    ...>  Bookmarks \n    ...>  Bookmarks \n    ...>   \n    ...>     Example \n    ...>   \n    ...> \"\"\"\n    iex> {:ok, bookmarks} = BookmarkParser.parse_string(content)\n    iex> bookmarks.title\n    \"Bookmarks\"\n    iex> flat_list = BookmarkParser.flatten(bookmarks)\n    iex> length(flat_list) > 0\n    true\n    iex> Enum.all?(flat_list, fn entry -> Map.has_key?(entry, :href) end)\n    true","ref":"BookmarkParser.html#module-examples"},{"type":"function","title":"BookmarkParser.count_entries/1","doc":"Counts the total number of bookmark entries in the tree.","ref":"BookmarkParser.html#count_entries/1"},{"type":"function","title":"Parameters - BookmarkParser.count_entries/1","doc":"- bookmark_tree: A BookmarkFolder or BookmarkEntry struct","ref":"BookmarkParser.html#count_entries/1-parameters"},{"type":"function","title":"Returns - BookmarkParser.count_entries/1","doc":"- Integer count of bookmark entries","ref":"BookmarkParser.html#count_entries/1-returns"},{"type":"function","title":"BookmarkParser.filter_bookmarks/2","doc":"Filters bookmarks by a given predicate function.","ref":"BookmarkParser.html#filter_bookmarks/2"},{"type":"function","title":"Parameters - BookmarkParser.filter_bookmarks/2","doc":"- bookmark_tree: A BookmarkFolder or BookmarkEntry struct\n  - predicate: Function that takes a BookmarkEntry and returns boolean","ref":"BookmarkParser.html#filter_bookmarks/2-parameters"},{"type":"function","title":"Returns - BookmarkParser.filter_bookmarks/2","doc":"- List of BookmarkEntry structs that match the predicate","ref":"BookmarkParser.html#filter_bookmarks/2-returns"},{"type":"function","title":"BookmarkParser.flatten/1","doc":"Flattens a bookmark tree structure into a list of BookmarkEntry structs.","ref":"BookmarkParser.html#flatten/1"},{"type":"function","title":"Parameters - BookmarkParser.flatten/1","doc":"- bookmark_tree: A BookmarkFolder or BookmarkEntry struct","ref":"BookmarkParser.html#flatten/1-parameters"},{"type":"function","title":"Returns - BookmarkParser.flatten/1","doc":"- List of BookmarkEntry structs","ref":"BookmarkParser.html#flatten/1-returns"},{"type":"function","title":"BookmarkParser.parse_file/1","doc":"Parses a bookmark file and returns a tree structure of folders and entries.","ref":"BookmarkParser.html#parse_file/1"},{"type":"function","title":"Parameters - BookmarkParser.parse_file/1","doc":"- path: The file path to the bookmark file","ref":"BookmarkParser.html#parse_file/1-parameters"},{"type":"function","title":"Returns - BookmarkParser.parse_file/1","doc":"- `{:ok, bookmark_folder}` on success with the parsed BookmarkFolder struct\n  - `{:error, reason}` on failure with reason for the error","ref":"BookmarkParser.html#parse_file/1-returns"},{"type":"function","title":"BookmarkParser.parse_string/1","doc":"Parses bookmark content from a string.","ref":"BookmarkParser.html#parse_string/1"},{"type":"function","title":"Parameters - BookmarkParser.parse_string/1","doc":"- content: String containing the bookmark HTML content","ref":"BookmarkParser.html#parse_string/1-parameters"},{"type":"function","title":"Returns - BookmarkParser.parse_string/1","doc":"- `{:ok, bookmark_folder}` on success with the parsed BookmarkFolder struct\n  - `{:error, reason}` on failure with reason for the error","ref":"BookmarkParser.html#parse_string/1-returns"},{"type":"module","title":"BookmarkParser.BookmarkEntry","doc":"Represents a single bookmark entry containing a URL.","ref":"BookmarkParser.BookmarkEntry.html"},{"type":"type","title":"BookmarkParser.BookmarkEntry.t/0","doc":"","ref":"BookmarkParser.BookmarkEntry.html#t:t/0"},{"type":"module","title":"BookmarkParser.BookmarkFolder","doc":"Represents a folder containing bookmarks or other folders.","ref":"BookmarkParser.BookmarkFolder.html"},{"type":"type","title":"BookmarkParser.BookmarkFolder.child/0","doc":"","ref":"BookmarkParser.BookmarkFolder.html#t:child/0"},{"type":"function","title":"BookmarkParser.BookmarkFolder.new/2","doc":"Creates a new bookmark folder.","ref":"BookmarkParser.BookmarkFolder.html#new/2"},{"type":"function","title":"Parameters - BookmarkParser.BookmarkFolder.new/2","doc":"- title: The name of the folder\n  - opts: Additional options (add_date, last_modified, personal_toolbar_folder)","ref":"BookmarkParser.BookmarkFolder.html#new/2-parameters"},{"type":"type","title":"BookmarkParser.BookmarkFolder.t/0","doc":"","ref":"BookmarkParser.BookmarkFolder.html#t:t/0"},{"type":"extras","title":"BookmarkParser","doc":"# BookmarkParser\n\n[![Hex.pm](https://img.shields.io/hexpm/v/bookmark_parser.svg)](https://hex.pm/packages/bookmark_parser)\n[![Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/bookmark_parser)\n\nBookmarkParser is an Elixir library for parsing Netscape-format HTML bookmark files exported from browsers like Chrome, Firefox, Safari, and others.","ref":"readme.html"},{"type":"extras","title":"Installation - BookmarkParser","doc":"The package can be installed by adding `bookmark_parser` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:bookmark_parser, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - BookmarkParser","doc":"```elixir\n# Parse a bookmark file\n{:ok, bookmarks} = BookmarkParser.parse_file(\"path/to/bookmarks.html\")\n\n# Parse bookmark content from a string\n{:ok, bookmarks} = BookmarkParser.parse_string(bookmark_content)\n\n# Get a flattened list of all bookmark entries\nentries = BookmarkParser.flatten(bookmarks)\n\n# Count total bookmark entries\ncount = BookmarkParser.count_entries(bookmarks)\n\n# Filter bookmarks\ngithub_bookmarks = BookmarkParser.filter_bookmarks(bookmarks, fn entry ->\n  String.contains?(entry.href, \"github.com\")\nend)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Structs - BookmarkParser","doc":"The parser produces two main types of structs:","ref":"readme.html#structs"},{"type":"extras","title":"BookmarkEntry - BookmarkParser","doc":"Represents a single bookmark with a URL.\n\n```elixir\n%BookmarkParser.BookmarkEntry{\n  href: \"https://example.com\",\n  title: \"Example Website\",\n  add_date: \"1622548800\",\n  last_modified: \"1622548800\",\n  icon: \"data:image/png;base64,...\",\n  tags: \"example,test\"\n}\n```","ref":"readme.html#bookmarkentry"},{"type":"extras","title":"BookmarkFolder - BookmarkParser","doc":"Represents a folder that can contain other bookmarks and folders.\n\n```elixir\n%BookmarkParser.BookmarkFolder{\n  title: \"My Bookmarks\",\n  add_date: \"1622548800\",\n  last_modified: \"1622548800\",\n  personal_toolbar_folder: false,\n  children: [list_of_entries_and_folders]\n}\n```","ref":"readme.html#bookmarkfolder"},{"type":"extras","title":"Documentation - BookmarkParser","doc":"Full documentation available at [https://hexdocs.pm/bookmark_parser](https://hexdocs.pm/bookmark_parser).","ref":"readme.html#documentation"},{"type":"extras","title":"License - BookmarkParser","doc":"This project is licensed under the MIT License - see LICENSE file for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.0"}}